@@ -113,6 +113,11 @@ public:
      */
     bool isTemporary();
 
+    /**
+     * Set modified value of project to \p modified.
+     */
+    void setModified(bool modified=true);
+
     /**
      * Returns true if the poject is modified.
      *
